'use strict';

const getTemplate = require('../src/index.js').getTemplate;
const http = require('http');
const livereload = require('livereload');
const path = require('path');
const fs = require('fs');

/**
 * Template name to test testing.
 *
 * Testing NOTES:
 *   1) set `loadTemplate` variable to desired test template
 *   2) start or restart server with `npm start`
 *   3) open the server in a browser
 *   4) server live reloads by watching for edits to in ./locals/ and the /template folder
 *
 * @property {string}
 */
const loadTemplate = '';
if (!loadTemplate) {
  console.log('!!! please set the <loadTemplate> variable. Examples:[default, welcome] !!!'); // eslint-disable-line no-console
  process.exit(1);
}

/**
 * Get output.
 *
 * @param {Object} results Results from `template`
 * @returns {string}
 */
function getOutput(results) {
  const style = `
    background: #fff;
    box-sizing: border-box;
    color: #000;
    font: normal 14px/150% Monaco, monospace;
    padding: 1em;
    white-space: pre-line;
    width: 100%;
  `.replace(/\s+/g, ' ');

  return `${results.html}
    <pre style="${style}">${results.text}</pre>
    <script>
      document.write(
        '<script src="http://' + (location.host || 'localhost').split(':')[0] +
        ':35729/livereload.js?snipver=1"></' + 'script>'
      )
    </script>`;
}

const port = 3000;
const server = http.createServer((request, response) => {
  const locals = JSON.parse(fs.readFileSync(path.resolve(__dirname, `./locals/${loadTemplate}.json`)));
  getTemplate(loadTemplate, locals)
    .then(results => response.end(getOutput(results)))
    .catch((error) => {
      console.error(error); // eslint-disable-line no-console
      response.writeHead(500);
      response.end(error.message);
    });
});

const livereloadServer = livereload.createServer({
  exts: ['scss', 'twig', 'json'],
});

livereloadServer.watch([
  path.resolve(__dirname, '..', getTemplate.TEMPLATES_DIR),
  path.resolve(__dirname, './locals/'),
]);

server.listen(port, (error) => {
  /* eslint-disable no-console */
  if (error) {
    console.error(error);
    server.close();
  } else {
    console.log('Server listening on: http://localhost:%s', port);
  }
  /* eslint-enable no-console */
});
